@@ -38,7 +38,7 @@ class SolarIrradiance:
                                                         "wvl": x[:, 0],
                                                         "irr": self.Q_(x[:, 1], 'mW/m**2/nm')}
                                              )(
-                np.array(pd.read_excel(path_thuillier, sheet_name="Thuillier 2002"), dtype=np.float))
+                np.array(pd.read_excel(path_thuillier, sheet_name="Thuillier 2002"), dtype=float))
         elif self.dataset == "Fontenla":
             path_fontenla = get_data_file("sicor", "SUNp1fontenla.asc")
             self.irr_unit = 'mW/m**2/nm'
