@@ -199,7 +199,7 @@ class RSImage(object):
             else:
                 bf = data[:, :][data[:, :] == self.bad_data_value]
 
-            pixel_skip = np.int(np.floor(bf.shape[0] / max_hist_pixel) + 1)
+            pixel_skip = int(np.floor(bf.shape[0] / max_hist_pixel) + 1)
             bf = bf[::pixel_skip]
             hh, xx = np.histogram(bf, bins=bins)
             bb = 0.5 * (xx[1:] + xx[:-1])
